# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs. As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import wds_client
from wds_client.models.version_response import VersionResponse  # noqa: E501
from wds_client.rest import ApiException

class TestVersionResponse(unittest.TestCase):
    """VersionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test VersionResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = wds_client.models.version_response.VersionResponse()  # noqa: E501
        if include_optional :
            return VersionResponse(
                app = wds_client.models.app.app(
                    chart_version = '0', 
                    image = '0', ), 
                git = wds_client.models.git.git(
                    branch = '0', 
                    commit = wds_client.models.commit.commit(
                        id = '0', 
                        time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                build = wds_client.models.build.build(
                    artifact = '0', 
                    name = '0', 
                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    version = '0', 
                    group = '0', )
            )
        else :
            return VersionResponse(
        )

    def testVersionResponse(self):
        """Test VersionResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
