# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs. As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import wds_client
from wds_client.models.status_response import StatusResponse  # noqa: E501
from wds_client.rest import ApiException

class TestStatusResponse(unittest.TestCase):
    """StatusResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StatusResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = wds_client.models.status_response.StatusResponse()  # noqa: E501
        if include_optional :
            return StatusResponse(
                status = '0', 
                components = wds_client.models.components.components(
                    db = wds_client.models.db_component.dbComponent(
                        status = '0', ), 
                    disk_space = wds_client.models.disk_space_component.diskSpaceComponent(
                        status = '0', 
                        details = wds_client.models.disk_space_component_details.diskSpaceComponentDetails(
                            total = '0', 
                            free = 1.337, 
                            threshold = 1.337, 
                            exists = True, ), ), 
                    ping = wds_client.models.component.component(
                        status = '0', ), 
                    main_db = wds_client.models.db_validationcomponent.dbValidationcomponent(
                        status = '0', ), )
            )
        else :
            return StatusResponse(
        )

    def testStatusResponse(self):
        """Test StatusResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
